Ian Jauslin
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/kondo.h')
-rw-r--r--src/kondo.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/kondo.h b/src/kondo.h
index c534145..18488ae 100644
--- a/src/kondo.h
+++ b/src/kondo.h
@@ -1,5 +1,5 @@
/*
-Copyright 2015 Ian Jauslin
+Copyright 2015-2022 Ian Jauslin
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
@@ -27,10 +27,10 @@ int kondo_generate_conf(Str_Array* str_args, int box_count);
// generate the Kondo fields table
int kondo_fields_table(int box_count, Char_Array* str_fields, Fields_Table* fields);
-// generate Kondo symbols
-int kondo_symbols(Char_Array* str_symbols, int box_count, Fields_Table* fields);
-// generate Kondo symbols (older method: one symbol for each scalar product)
-int kondo_symbols_scalarprod(Char_Array* str_symbols, int box_count, Fields_Table* fields);
+// generate Kondo virtual_fields
+int kondo_virtual_fields(Char_Array* str_virtual_fields, int box_count, Fields_Table* fields);
+// generate Kondo virtual_fields (older method: one virtual_field for each scalar product)
+int kondo_virtual_fields_scalarprod(Char_Array* str_virtual_fields, int box_count, Fields_Table* fields);
// generate Kondo groups (groups of independent variables)
int kondo_groups(Char_Array* str_groups, int box_count);
@@ -71,6 +71,6 @@ int kondo_resolve_scalar_prod_symbols(char* str, Polynomial* output);
int get_offset_index(char* str, int* offset, int* index);
// get the offsets and index of a scalar product
int get_offsets_index(char* str, int* offset1, int* offset2, int* index);
-// get the index of the symbol corresponding to a given string
-int get_symbol_index(char* str);
+// get the index of the virtual_field corresponding to a given string
+int get_virtual_field_index(char* str);
#endif